===========
openwebifpy
===========


.. image:: https://img.shields.io/pypi/v/openwebifpy.svg
        :target: https://pypi.python.org/pypi/openwebifpy

.. image:: https://github.com/fbradyirl/openwebifpy/workflows/Python%20package/badge.svg
        :target: https://github.com/fbradyirl/openwebifpy/actions

.. image:: https://readthedocs.org/projects/openwebifpy/badge/?version=latest
        :target: https://openwebifpy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/fbradyirl/openwebifpy/shield.svg
     :target: https://pyup.io/repos/github/fbradyirl/openwebifpy/
     :alt: Updates



Provides a python interface to interact with a device running OpenWebIf


* Free software: MIT license
* Documentation: https://openwebifpy.readthedocs.io.
* OpenWebif API docs: https://github.com/E2OpenPlugins/e2openplugin-OpenWebif/wiki/OpenWebif-API-documentation

Features
--------

* Basic control of an Enigma2 box running OpenWebif.
* Ability to send messages to the screen.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
